#ifndef HELLOSIGNALSLOT_H
#define HELLOSIGNALSLOT_H

#include <QObject>

// A signal-slot example class
class HelloSignalSlot : public QObject
{
    // QObject-based objects need to have Q_OBJECT macro
    // in the header in order to be processed by moc.
    // Although, there's an exeption: If the class doesn't
    // have signals, slots or properties this isn't strictly
    // necessary since there's nothing for the moc to process
    Q_OBJECT

public:
    // The new class wizard generates an explicit constructor.
    // It prevents implicit type conversions when creating the object.
    // See for example:
    // http://choorucode.wordpress.com/2010/12/17/c-explicit-constructor/
    // Usually QObject-based class constructor takes the parent parameter
    // and uses NULL-pointer (==0) as default value. Thus, the constructor
    // can be called with or without a parent object.
    // If you have more constructor parameters, set the parent as last one.
    explicit HelloSignalSlot(QObject *parent = 0);

signals:
    // A signal function is defined in the header, but is not implemented
    // in the source code. The code for it is generated by moc.
    void helloSignal();

public slots:
    // From C++ point of view a slot is just a normal function.
    // If called directly, the public / protected / private
    // rules are enforced. Signal-slot connections can circumvent
    // the protection rules, but in general public slots are meant
    // to be used from outside and private ones are for internal use.
    void hello();

};

#endif // HELLOSIGNALSLOT_H
